@@ -24,9 +24,8 @@ use crate::geom::Point;
 use crate::geom::Rect;
 use crate::geom::Size;
 
-use crate::geom::HorizontalPosition;
 use crate::geom::PointPosition;
-use crate::geom::VerticalPosition;
+use crate::geom::Transform;
 
 use crate::Random;
 
@@ -126,16 +125,7 @@ where
             return Some(self);
         }
 
-        // Is either fully above, or fully below.
-        if position.is_on_same_horizontal()
-            && position.start().horizontal() != HorizontalPosition::Inside
-        {
-            return None;
-        }
-
-        // Is either fully on the left, or fully on the right.
-        if position.is_on_same_vertical() && position.start().vertical() != VerticalPosition::Inside
-        {
+        if position.is_entirely_outside() {
             return None;
         }
 
@@ -514,6 +504,14 @@ impl<N: Num + Signed> Neg for Line<N> {
     }
 }
 
+impl Add<Transform> for Line {
+    type Output = Line;
+
+    fn add(self, transform: Transform) -> Self::Output {
+        transform + self
+    }
+}
+
 impl<N: Num> From<(Point<N>, Point<N>)> for Line<N> {
     fn from((start, end): (Point<N>, Point<N>)) -> Self {
         Self(start, end)
